embassy-net

Crates

git

Versions

default

Flavors

TcpControl

Enum TcpControl 

pub enum TcpControl {
    None,
    Psh,
    Syn,
    Fin,
    Rst,
}
The possible control flags of a Transmission Control Protocol packet.

Variants



None



Psh



Syn



Fin



Rst

Implementations



impl Control

pub const fn len(self) -> usize

Return the length of a control flag, in terms of sequence space.

pub const fn quash_psh(self) -> Control

Turn the PSH flag into no flag, and keep the rest as-is.