Struct Icmpv6Message
pub struct Icmpv6Message(pub u8);Expand description
Internet protocol control message type.
Tuple Fields
0: u8Implementations
impl Message
impl Message
pub const DstUnreachable: Message
pub const DstUnreachable: Message
Destination Unreachable.
pub const TimeExceeded: Message
pub const TimeExceeded: Message
Time Exceeded.
pub const ParamProblem: Message
pub const ParamProblem: Message
Parameter Problem.
pub const EchoRequest: Message
pub const EchoRequest: Message
Echo Request
pub const RouterSolicit: Message
pub const RouterSolicit: Message
Router Solicitation
pub const RouterAdvert: Message
pub const RouterAdvert: Message
Router Advertisement
pub const NeighborSolicit: Message
pub const NeighborSolicit: Message
Neighbor Solicitation
pub const NeighborAdvert: Message
pub const NeighborAdvert: Message
Neighbor Advertisement
pub const RplControl: Message
pub const RplControl: Message
RPL Control Message
impl Message
impl Message
pub fn is_error(&self) -> bool
pub fn is_error(&self) -> bool
Per RFC 4443  2.1 ICMPv6 message types with the highest order bit set are informational messages while message types without the highest order bit set are error messages.