Struct MldRecordType
pub struct MldRecordType(pub u8);Expand description
MLDv2 Multicast Listener Report Record Type. See RFC 3810  5.2.12 for more details.
Tuple Fields
0: u8Implementations
impl RecordType
impl RecordType
pub const ModeIsInclude: RecordType
pub const ModeIsInclude: RecordType
Interface has a filter mode of INCLUDE for the specified multicast address.
pub const ModeIsExclude: RecordType
pub const ModeIsExclude: RecordType
Interface has a filter mode of EXCLUDE for the specified multicast address.
pub const ChangeToInclude: RecordType
pub const ChangeToInclude: RecordType
Interface has changed to a filter mode of INCLUDE for the specified multicast address.
pub const ChangeToExclude: RecordType
pub const ChangeToExclude: RecordType
Interface has changed to a filter mode of EXCLUDE for the specified multicast address.
pub const AllowNewSources: RecordType
pub const AllowNewSources: RecordType
Interface wishes to listen to the sources in the specified list.
pub const BlockOldSources: RecordType
pub const BlockOldSources: RecordType
Interface no longer wishes to listen to the sources in the specified list.