Struct NdiscRouterFlags
pub struct NdiscRouterFlags(/* private fields */);Implementations
impl RouterFlags
impl RouterFlags
pub const MANAGED: RouterFlags
pub const OTHER: RouterFlags
impl RouterFlags
impl RouterFlags
pub const fn empty() -> RouterFlags
pub const fn empty() -> RouterFlags
Get a flags value with all bits unset.
pub const fn all() -> RouterFlags
pub const fn all() -> RouterFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<RouterFlags>
pub const fn from_bits(bits: u8) -> Option<RouterFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> RouterFlags
pub const fn from_bits_truncate(bits: u8) -> RouterFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> RouterFlags
pub const fn from_bits_retain(bits: u8) -> RouterFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<RouterFlags>
pub fn from_name(name: &str) -> Option<RouterFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: RouterFlags) -> bool
pub const fn intersects(&self, other: RouterFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: RouterFlags) -> bool
pub const fn contains(&self, other: RouterFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: RouterFlags)
pub fn insert(&mut self, other: RouterFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: RouterFlags)
pub fn remove(&mut self, other: RouterFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: RouterFlags)
pub fn toggle(&mut self, other: RouterFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: RouterFlags, value: bool)
pub fn set(&mut self, other: RouterFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: RouterFlags) -> RouterFlags
pub const fn intersection(self, other: RouterFlags) -> RouterFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: RouterFlags) -> RouterFlags
pub const fn union(self, other: RouterFlags) -> RouterFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: RouterFlags) -> RouterFlags
pub const fn difference(self, other: RouterFlags) -> RouterFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: RouterFlags) -> RouterFlags
pub const fn symmetric_difference(self, other: RouterFlags) -> RouterFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> RouterFlags
pub const fn complement(self) -> RouterFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl RouterFlags
impl RouterFlags
pub const fn iter(&self) -> Iter<RouterFlags> ⓘ
pub const fn iter(&self) -> Iter<RouterFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<RouterFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<RouterFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.